@@ -133,22 +133,21 @@ void vtkFillImageWithPolyDataExecuteZ(vtkFillImageWithPolyData *self,
                                       unsigned char *outPtr,
                                       int id, int slice, double bbox[6])
 {
-  int           num0, num1, num2, numC, pixSize;
   int           idx0, idx1, idx2;
   vtkIdType     in1Inc0, in1Inc1, in1Inc2;
   vtkIdType     outInc0, outInc1, outInc2;
   unsigned long count = 0;
   unsigned long target;
 
-  numC = outData->GetNumberOfScalarComponents();
-  pixSize = numC * static_cast< int >( sizeof( T ) );
+//  numC = outData->GetNumberOfScalarComponents();
+//  pixSize = numC * static_cast< int >( sizeof( T ) );
 
   // Get information to march through data
   inData->GetContinuousIncrements(ext, in1Inc0, in1Inc1, in1Inc2);
   outData->GetContinuousIncrements(ext, outInc0, outInc1, outInc2);
-  num0 = ext[1] - ext[0] + 1;
-  num1 = ext[3] - ext[2] + 1;
-  num2 = ext[5] - ext[4] + 1;
+  int num0 = ext[1] - ext[0] + 1;
+  int num1 = ext[3] - ext[2] + 1;
+  int num2 = ext[5] - ext[4] + 1;
 
   double outVal = self->GetInsidePixelValue();
 
@@ -226,22 +225,21 @@ void vtkFillImageWithPolyDataExecuteY(vtkFillImageWithPolyData *self, int ext[6]
                                       vtkImageData *outData, unsigned char *outPtr,
                                       int id, int slice, double bbox[6])
 {
-  int           num0, num1, num2, numC;
   int           idx0, idx1, idx2;
   vtkIdType     in1Inc0, in1Inc1, in1Inc2;
   vtkIdType     outInc0, outInc1, outInc2;
   unsigned long count = 0;
   unsigned long target;
 
-  numC = outData->GetNumberOfScalarComponents();
+//  numC = outData->GetNumberOfScalarComponents();
 //   int pixSize = numC * static_cast<int>(sizeof(T));
 
   // Get information to march through data
   inData->GetContinuousIncrements(ext, in1Inc0, in1Inc1, in1Inc2);
   outData->GetContinuousIncrements(ext, outInc0, outInc1, outInc2);
-  num0 = ext[1] - ext[0] + 1;
-  num1 = ext[3] - ext[2] + 1;
-  num2 = ext[5] - ext[4] + 1;
+  int num0 = ext[1] - ext[0] + 1;
+  int num1 = ext[3] - ext[2] + 1;
+  int num2 = ext[5] - ext[4] + 1;
 
   vtkPoints *points = self->GetPolyData()->GetPoints();
   vtkIdType  numP = self->GetPolyData()->GetNumberOfPoints();
@@ -319,15 +317,15 @@ void vtkFillImageWithPolyDataExecuteX(vtkFillImageWithPolyData *self, int ext[6]
                                       vtkImageData *outData, unsigned char *outPtr,
                                       int id, int slice, double bbox[6])
 {
-  int           num0, num1, num2, numC, pixSize;
+  int           num0, num1, num2;
   int           idx0, idx1, idx2;
   vtkIdType     in1Inc0, in1Inc1, in1Inc2;
   vtkIdType     outInc0, outInc1, outInc2;
   unsigned long count = 0;
   unsigned long target;
 
-  numC = outData->GetNumberOfScalarComponents();
-  pixSize = numC * static_cast< int >( sizeof( T ) );
+//  numC = outData->GetNumberOfScalarComponents();
+//  pixSize = numC * static_cast< int >( sizeof( T ) );
 
   // Get information to march through data
   inData->GetContinuousIncrements(ext, in1Inc0, in1Inc1, in1Inc2);
@@ -520,4 +518,4 @@ double vtkFillImageWithPolyData::Angle2D(const double dp1[2], const double dp2[2
     }
 
   return dt;
-}
\ No newline at end of file
+}
