@@ -173,7 +173,7 @@ public:
     */
   void EnablePickMode();
 
-  void SetPlanesActors( std::vector< vtkActor * > iBounds);
+  void SetPlanesActors( std::vector< vtkProp3D * > iBounds);
 
 protected:
   vtkInteractorStyleImage3D();
@@ -189,7 +189,7 @@ private:
   unsigned int m_Mode;
   bool         m_State;
 
-  std::vector< vtkActor * > m_PlanesActors;
+  std::vector< vtkProp3D * > m_PlanesActors;
 };
 
 #endif
