@@ -38,18 +38,22 @@
 #include <QVBoxLayout>
 #include <QShortcut>
 
+#include <QCheckBox>
+#include <QPushButton>
+
+#include <QtDebug>
+
 QGoNavigationDockWidget::
 QGoNavigationDockWidget( QWidget *iParent,
                          const GoFigure::TabDimensionType & iDim ) :
-  QDockWidget(iParent),
+  QGoDockWidget(iParent),
   m_Dimension(iDim)
 {
   this->setupUi(this);
   QIcon Navigation;
   Navigation.addPixmap(QPixmap( QString::fromUtf8(":/fig/navigation.png") ),
                        QIcon::Normal, QIcon::Off);
-  //temp->setIcon(Navigation);
-  this->toggleViewAction()->setIcon(Navigation);
+  this->m_ToggleAction->setIcon(Navigation);
 
   switch ( m_Dimension )
     {
@@ -64,8 +68,6 @@ QGoNavigationDockWidget( QWidget *iParent,
       this->TSliceLbl->setVisible(false);
       this->TSliceSpinBox->setVisible(false);
 
-      this->line->setVisible(false);
-
       break;
       }
     case GoFigure::TWO_D_WITH_T:
@@ -105,14 +107,15 @@ QGoNavigationDockWidget( QWidget *iParent,
   QObject::connect( this->TSliceSpinBox, SIGNAL( valueChanged(int) ),
                     this, SIGNAL( TSliceChanged(int) ) );
 
-  QObject::connect( this->AllChannelsBtn, SIGNAL( toggled(bool) ),
-                    this, SIGNAL( ShowAllChannelsChanged(bool) ) );
-
-  QObject::connect( this->ChannelComboBox, SIGNAL( currentIndexChanged(int) ),
-                    this, SIGNAL( ShowOneChannelChanged(int) ) );
-
+  // doppler view specific widgets
+  this->channelLabel->hide();
+  this->channelName->hide();
   this->stepLabel->hide();
   this->step->hide();
+  this->tLabel->hide();
+  this->t->hide();
+
+  m_Classic = true;
 }
 
 //-------------------------------------------------------------------------
@@ -157,47 +160,6 @@ void QGoNavigationDockWidget::SetTSlice(int iSlice)
 
 //-------------------------------------------------------------------------
 
-//-------------------------------------------------------------------------
-void
-QGoNavigationDockWidget::SetNumberOfChannels(const unsigned int & iN)
-{
-  if ( iN < 2 )
-    {
-    this->line->setVisible(false);
-    this->AllChannelsBtn->setVisible(false);
-    this->OneChannelBtn->setVisible(false);
-    this->ChannelComboBox->setVisible(false);
-    }
-  else
-    {
-    this->line->setVisible(true);
-    this->AllChannelsBtn->setVisible(true);
-    this->OneChannelBtn->setVisible(true);
-    this->ChannelComboBox->setMaxCount(iN);
-    }
-}
-
-//-------------------------------------------------------------------------
-
-//-------------------------------------------------------------------------
-void
-QGoNavigationDockWidget::SetChannel(const unsigned int & i, const QString & iText)
-{
-  QString input;
-
-  if ( !iText.isEmpty() )
-    {
-    input = iText;
-    }
-  else
-    {
-    input = QString("Channel %1").arg(i);
-    }
-  this->ChannelComboBox->insertItem(i, input);
-}
-
-//-------------------------------------------------------------------------
-
 //-------------------------------------------------------------------------
 void QGoNavigationDockWidget::SetXMinimumAndMaximum(const int & iMin, const int & iMax)
 {
@@ -207,7 +169,6 @@ void QGoNavigationDockWidget::SetXMinimumAndMaximum(const int & iMin, const int
     this->XSliceSpinBox->setMaximum(iMax);
     this->XSliceSlider->setMinimum(iMin);
     this->XSliceSlider->setMaximum(iMax);
-    //this->MinXSlicelbl->setText(ConvertToString<int>(iMin).c_str());
     this->MinXSlicelbl->setText( tr("%1").arg(iMin) );
     this->MaxXSlicelbl->setText( tr("%1").arg(iMax) );
     }
@@ -287,51 +248,33 @@ void QGoNavigationDockWidget::SetTMinimumAndMaximum(const int & iMin, const int
                       this, SIGNAL( ModeChanged(int) ) );
 
     QObject::connect( this->ModeComboBox, SIGNAL( activated(int) ),
-                      this, SLOT( StepVisibility(int) ) );
+                      this, SLOT( UpdateWidget(int) ) );
 
     QObject::connect( this->step, SIGNAL( valueChanged(int) ),
                       this, SIGNAL( StepChanged(int) ) );
+
+    QObject::connect( this->t, SIGNAL( valueChanged(int) ),
+                      this, SIGNAL( DopplerSizeChanged(int) ) );
     }
   else
     {
-    this->line_2->hide();
     this->TSliceLbl->hide();
     this->TSliceSpinBox->hide();
     this->TSliceSlider->hide();
     this->MinTSlicelbl->hide();
     this->MaxTSlicelbl->hide();
     this->ModeComboBox->hide();
+    this->channelLabel->hide();
+    this->channelName->hide();
     this->stepLabel->hide();
     this->step->hide();
+    this->tLabel->hide();
+    this->t->hide();
     }
 }
 
 //-------------------------------------------------------------------------
 
-//-------------------------------------------------------------------------
-int QGoNavigationDockWidget::GetCurrentChannel() const
-{
-  return this->ChannelComboBox->currentIndex();
-}
-
-//-------------------------------------------------------------------------
-
-//-------------------------------------------------------------------------
-bool QGoNavigationDockWidget::ShowAllChannels() const
-{
-  return this->AllChannelsBtn->isChecked();
-}
-
-//-------------------------------------------------------------------------
-
-//-------------------------------------------------------------------------
-QString QGoNavigationDockWidget::GetChannelName(const int & iIdx)
-{
-  return this->ChannelComboBox->itemText(iIdx);
-}
-
-//-------------------------------------------------------------------------
-
 //-------------------------------------------------------------------------
 void QGoNavigationDockWidget::MoveToPreviousTimePoint()
 {
@@ -355,16 +298,191 @@ void QGoNavigationDockWidget::MoveToNextTimePoint()
 //-------------------------------------------------------------------------
 
 //-------------------------------------------------------------------------
-void QGoNavigationDockWidget::StepVisibility(int iStep)
+void QGoNavigationDockWidget::UpdateWidget(int iStep)
 {
   if ( iStep == 0 )
     {
-    this->step->hide();
+    this->channelLabel->hide();
+    this->channelName->hide();
     this->stepLabel->hide();
+    this->step->hide();
+    this->tLabel->hide();
+    this->t->hide();
     }
   else
     {
-    this->step->show();
+    this->channelLabel->show();
+    this->channelName->show();
     this->stepLabel->show();
+    this->step->show();
+    this->tLabel->show();
+    this->t->show();
     }
 }
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget::
+AddChannel(const QString& iName, const QColor& iColor, const unsigned int& iNumber,
+           const bool& iChecked)
+{
+  // create check box + colored push button
+  QCheckBox *checkBox1 = new QCheckBox(iName, this);
+  checkBox1->setObjectName(iName);
+  checkBox1->setChecked(iChecked);
+  QString style = "border: 1px solid black; background-color: rgba(%1, %2, %3, 150); border-radius: 4px;";
+  checkBox1->setStyleSheet(
+        style.arg(iColor.red()).arg(iColor .green()).arg(iColor.blue()));
+  QHBoxLayout *layout = new QHBoxLayout;
+  layout->addWidget(checkBox1);
+  // to be modified - 7
+  this->gridLayout_2->addLayout(layout, 7+iNumber, 0, 0);
+  //create signals connections
+  QObject::connect( checkBox1, SIGNAL( clicked(bool) ),
+                    this, SLOT( visibilityChanged(bool) ) );
+
+  // vector of widget so we can remove it from layout efficiently
+  m_ListCheckBoxes.push_back(checkBox1);
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget::
+ModifyChannel(QString iName, QColor iColor)
+{
+  //modify color of bg of checkbox!
+  QList<QCheckBox*>::iterator it2;
+
+  // doppler view or not?
+  if(m_Classic)
+    {
+    it2 = m_ListCheckBoxes.begin();
+    }
+  else
+    {
+    it2 = m_ListDoppler.begin();
+    }
+
+  while(iName.compare((*it2)->objectName()) != 0)
+    {
+    ++it2;
+    }
+
+  QString style = "border: 1px solid black; background-color: rgba(%1, %2, %3, 150); border-radius: 4px;";
+  (*it2)->setStyleSheet(
+        style.arg(iColor.red()).arg(iColor .green()).arg(iColor.blue()));
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget::
+visibilityChanged(bool iVisibility)
+{
+  emit visibilityChanged(QObject::sender()->objectName(), iVisibility);
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget::
+VisibilityListChannels(const bool& iVisibility)
+{
+  QList<QCheckBox*>::iterator it = m_ListCheckBoxes.begin();
+  while(it != m_ListCheckBoxes.end())
+    {
+    (*it)->setVisible(iVisibility);
+    (*it)->setChecked(iVisibility);
+    ++it;
+    }
+
+  QList<QPushButton*>::iterator it2 = m_ListPushButtons.begin();
+  while(it2 != m_ListPushButtons.end())
+    {
+    (*it2)->setVisible(iVisibility);
+    ++it2;
+    }
+
+  m_Classic = iVisibility;
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget::
+AddDoppler(const QString& iName, const QColor& iColor, const unsigned int& iNumber,
+           const bool& iChecked)
+{
+  // create check box + colored push button
+  QCheckBox *checkBox1 = new QCheckBox(iName, this);
+  checkBox1->setObjectName(iName);
+  checkBox1->setChecked(iChecked);
+  QString style = "border: 1px solid black; background-color: rgba(%1, %2, %3, 100); border-radius: 4px;";
+  checkBox1->setStyleSheet(
+        style.arg(iColor.red()).arg(iColor .green()).arg(iColor.blue()));
+  QHBoxLayout *layout = new QHBoxLayout;
+  layout->addWidget(checkBox1);
+  // to be modified - 7
+  this->gridLayout_2->addLayout(layout, 7+iNumber, 0, 0);
+  //create signals connections
+  QObject::connect( checkBox1, SIGNAL( clicked(bool) ),
+                    this, SLOT( visibilityChanged(bool) ) );
+  // more signals for modify LUT
+
+  // vector of widget so we can remove it from layout efficiently
+  m_ListDoppler.push_back(checkBox1);
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget::
+VisibilityListDoppler(const bool& iVisibility)
+{
+  QList<QCheckBox*>::iterator it = m_ListDoppler.begin();
+  while(it != m_ListDoppler.end())
+  {
+    (*it)->setVisible(iVisibility);
+    ++it;
+  }
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget::
+setChannelName(QString iChannelName)
+{
+  this->channelName->setText(iChannelName);
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+void
+QGoNavigationDockWidget:: DeleteDopplerWidgets()
+{
+  qDeleteAll(m_ListDoppler.begin(), m_ListDoppler.end());
+  m_ListDoppler.clear();
+}
+//-------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+int
+QGoNavigationDockWidget::
+GetFirstVisibleChannel()
+{
+  int index = 0;
+  QList<QCheckBox*>::iterator it2 = m_ListCheckBoxes.begin();
+  while( it2 != m_ListCheckBoxes.end() )
+    {
+    if((*it2)->isChecked())
+      {
+      return index;
+      }
+    ++index;
+    ++it2;
+    }
+  return -1;
+}
