@@ -34,11 +34,11 @@
 #ifndef __QGoPrintDatabase_h
 #define __QGoPrintDatabase_h
 
-#include <QWidget>
+#include <QDockWidget>
 #include <QTableWidget>
 #include <QColor>
 #include <string>
-#include "ui_QGoPrintDatabase.h"
+#include <QStackedWidget>
 #include "MegaVTK2Configure.h"
 #include "GoDBRecordSet.h"
 #include "GoDBContourRow.h"
@@ -50,17 +50,18 @@
 #include "QGoDBBookmarkManager.h"
 #include "QGoGUILibConfigure.h"
 #include "GoFigureMeshAttributes.h"
-#include "QGoTraceManualEditingDockWidget.h"
-#include "QGoTraceManualEditingWidget.h"
+#include "QGoTraceSettingsWidget.h"
 #include "QGoDBCellTypeManager.h"
 #include "QGoDBSubCellTypeManager.h"
 #include "QGoDBColorManager.h"
 #include "QGoDBMeshManager.h"
 #include "QGoDBContourManager.h"
 #include "QGoDBTrackManager.h"
+#include "QGoDBLineageManager.h"
 #include "ContourContainer.h"
 #include "MeshContainer.h"
 #include "TrackContainer.h"
+#include "QGoDockWidget.h"
 /**
 \defgroup DB Database
 \defgroup GUI GUI
@@ -68,12 +69,11 @@
 
 /**
 \class QGoPrintDatabase
-\brief manages all the database components: table widget, trace manual editing widdet,
+\brief manages all the database components: table widget, trace settings editing widdet,
 QGoDBTraceManager...
 \ingroup DB GUI
 */
-class QGOGUILIB_EXPORT QGoPrintDatabase:public QWidget,
-  private Ui::WidgetPrintDatabase
+class QGOGUILIB_EXPORT QGoPrintDatabase:public QGoDockWidget
 {
   Q_OBJECT
 public:
@@ -86,7 +86,7 @@ public:
 
   typedef GoDBCollectionOfTraces::TWContainerType            TWContainerType;
   typedef QGoDBBookmarkManager::NamesDescrContainerType      NamesDescrContainerType;
-  typedef QGoTraceManualEditingWidget::ItemColorComboboxData ItemColorComboboxData; 
+  typedef QGoTraceSettingsWidget::ItemColorComboboxData  ItemColorComboboxData;
   typedef std::pair< int, QColor >                           IDWithColorData;
 
   /** \brief set all the values needed for the database*/
@@ -98,7 +98,7 @@ public:
   /** \brief Create the QTableWidgetChild,get the columns names and the
  * values stored in the database, display them in the QTableWidgetChild
  * and fill the info for the contours and meshes*/
-  void FillTableFromDatabase();
+  void FillTableFromDatabase( const unsigned int& iTreshold);
 
   /** \brief Return a vector of all the contours for the given timepoint*/
   std::vector< ContourMeshStructure > GetContoursForAGivenTimepoint(
@@ -124,6 +124,8 @@ public:
   visualization, if the mesh is an updated mesh which already exists(for
   example a new contour is added to this mesh, the NewMesh has to be set
   to false
+  \param[in] iTrackID Track ID we want the mesh to belong to.
+   if -1, we get the track ID from the trace editing widget.
   */
   void SaveMeshFromVisuInDB(unsigned int iXCoordMin,
                             unsigned int iYCoordMin,
@@ -131,8 +133,10 @@ public:
                             unsigned int iXCoordMax,
                             unsigned int iYCoordMax,
                             unsigned int iZCoordMax,
-                            int          iTShift,
-                            vtkPolyData *iMeshNodes, GoFigureMeshAttributes *iMeshAttributes);
+                            int iTCoord,
+                            vtkPolyData *iMeshNodes,
+                            GoFigureMeshAttributes *iMeshAttributes,
+                            int iTrackID = -1);
 
   /**
   \brief save a new contour in the database, the TW and the container for the contours to sphere
@@ -169,7 +173,7 @@ public:
  * not*/
   bool IsDatabaseUsed();
 
-  QAction * toggleViewAction();
+  //QAction * toggleViewAction();
 
   /**
   \brief get the info from a textfile, save it into the database,
@@ -193,7 +197,7 @@ public:
 
   /**
   \brief display in the table widget the volume and area from iMeshAttributes
-  for iMeshID 
+  for iMeshID
   \param[in] iMeshAttributes contains the values to be displayed
   \param[in] iMeshID ID of the mesh
   */
@@ -202,31 +206,28 @@ public:
 
   /**
   \brief display in the table widget the values from iTrackAttributes
-  for iTrackID 
+  for iTrackID
   \param[in] iTrackAttributes contains the values to be displayed
   \param[in] iTrackID ID of the track
   */
   void PrintCalculatedValuesForTrack(GoFigureTrackAttributes *
                         iTrackAttributes, unsigned int iTrackID);
 
-  /** \brief return the TraceManualEditingDockWidget*/
-  QGoTraceManualEditingDockWidget * GetTraceManualEditingDockWidget();
+  /** \brief return the TraceSettingsDockWidget*/
+  QGoTraceSettingsWidget*  GetTraceSettingsWidget();
+
+  QGoTraceSettingsWidget*  GetTraceSettingsWidgetForToolBar();
 
   /**
-  \brief update the tracemanualeditingwidget for the trace with the
+  \brief update the traceSettingswidget for the trace with the
   corresponding list of collectionID and set the tablewidget for the
   trace table
   \param[in] iTraceName name of the corresponding trace
-  \param[in] iCollectionName name of the corresponding collection
-  \param[in] UpdateTableWidget true if the tablewidget has to be
-  updated also
   */
-  void UpdateWidgetsForCorrespondingTrace(std::string iTraceName,
-                                          std::string iCollectionName, 
-                                          bool UpdateTableWidget = true);
+  void SetTraceNameForTableWidget(std::string iTraceName);
 
   /** \brief Initialize or reinitialized the celltype,subcelltype
-  and color list from the database into the tracemanualeditingwidget*/
+  and color list from the database into the traceSettingswidget*/
   void InitializeTheComboboxesNotTraceRelated();
 
   /**
@@ -253,10 +254,39 @@ public:
   */
   void SetTracksContainer(TrackContainer *iContainer);
 
+  /**
+  \brief set the pointer m_LineageInfoForVisu of the LineagesManager to
+  iContainer
+  \param[in] iContainer pointer for the container of lineages
+  for the visu
+  \Param[in] iTrackContainer pointer for the container of tracks
+  */
+  void SetLineagesContainers(LineageContainer *iContainer,
+    TrackContainer *iTrackContainer);
+
+  /**
+  \brief check if the tracesettingsWidget is visible, if not,
+  return true.
+  */
+  bool NeedTraceSettingsToolBarVisible();
+
+  /**
+    \brief Update the table widget and the visualization container contents
+    based on the given time point and the previous visible time points.
+    It erases actors and remove them from the visualization.
+    It doesn't create actors after adding polydata to container.
+    */
+  std::list<unsigned int> UpdateTableWidgetAndContainersForGivenTimePoint(
+          const unsigned int& iNewTimePoint);
+
+  std::list<unsigned int> GetVisibleTimePoints();
+
+  int GetNumberOfElementForTraceAndTimePoint(std::string iTrace, int iTimePoint);
+
 public slots:
   void DeleteBookmarks();
 
-  void SetTable(std::string iTablename);
+  //void SetTable(std::string iTablename);
 
   void ExportContours();
 
@@ -275,8 +305,6 @@ signals:
 
   void OpenBookmarksToUpdate();
 
-  void TableWidgetTabChanged();
-
   void NewMeshToGenerate(std::list< unsigned int > ListContourIDs, int iNewMeshID);
 
   /**
@@ -285,6 +313,8 @@ signals:
   */
   void NeedToGoToTheLocation(int XCoord, int YCoord, int ZCoord, int TCoord);
 
+  void NeedToGoToTheRealLocation(double XCoord, double YCoord, double ZCoord, int TCoord);
+
   void PrintMessage(QString iMessage, int iTimeOut = 0);
 
 protected:
@@ -292,16 +322,18 @@ protected:
   int*                  m_SelectedTimePoint;
   QGoDBBookmarkManager* m_BookmarkManager;
 
-  //related to TraceManualEditing Widget:
+  //related to TraceSettings Widget:
   QGoDBCellTypeManager*             m_CellTypeManager;
   QGoDBSubCellTypeManager*          m_SubCellTypeManager;
   QGoDBColorManager*                m_ColorManager;
-  QGoTraceManualEditingDockWidget*  m_TraceManualEditingDockWidget;
-  QGoTraceManualEditingWidget*      m_TraceWidget;
+  QGoTraceSettingsWidget*           m_TraceSettingsWidget;
+  QGoTraceSettingsWidget*           m_TraceSettingsWidgetForToolBar;
 
   QGoDBContourManager*              m_ContoursManager;
   QGoDBMeshManager*                 m_MeshesManager;
   QGoDBTrackManager*                m_TracksManager;
+  QGoDBLineageManager*              m_LineagesManager;
+  QStackedWidget*                   m_StackedTables;
 
   //Database variables:
   vtkMySQLDatabase* m_DatabaseConnector;
@@ -315,11 +347,17 @@ protected:
 
   bool m_ReeditMode;
   bool m_MeshGenerationMode;
-
-  QAction*  m_VisibilityAction;
+  bool m_TraceSettingsVisible;
 
   void OpenDBConnection();
 
+  void SetUpUi();
+
+  /**
+  \brief set the tracesettings widget to be in the mainwindow toolbar and the connection
+  between the 2 instances of tracesettingswidget
+  */
+  void SetConnectionsBetweenTheInstancesOfTraceSettings();
   /**
   \brief create the m_ContoursManager and its SLOT/SIGNAL connection
   */
@@ -335,60 +373,65 @@ protected:
  */
   void SetTracksManager();
 
-  //******************Methods related to Trace Manual Editing Widget***********
+  /**
+ \brief create the m_LineagesManager and its SLOT/SIGNAL connection
+ */
+  void SetLineagesManager();
+
+  //******************Methods related to Trace Settings Editing Widget***********
 
   /**
   \brief create all the connections between the QGoPrintDatabase and the
-  QGoTraceManaualEditingWidget (TM)
+  QGoTraceSettingsWidget (TS)
   */
-  void CreateConnectionsForTraceManualEditingWidget();
+  void CreateConnectionsForTraceSettingsWidget(QGoTraceSettingsWidget* iTraceSettingsWidget);
 
   /**
   \brief get the list of celltypes from the database, put them in
-  the Trace Manual combobox and if the string is not empty, the combobox will have as
+  the Trace Settings combobox and if the string is not empty, the combobox will have as
   selected item the string
   \param[in] iCellTypeToSelect name of the celltype to be selected
   */
-  void SetTMListCellTypes(std::string iCellTypeToSelect = "");
+  void SetTSListCellTypes(std::string iCellTypeToSelect = "");
 
   /**
   \brief get the list of celltypes from the database, put them in
-  the Trace Manual combobox and the combobox will have as selected item the one
+  the Trace Settings combobox and the combobox will have as selected item the one
   previously selected
   */
-  void SetTMListCellTypesWithPreviousSelectedOne();
+  void SetTSListCellTypesWithPreviousSelectedOne();
 
   /**
   \brief get the list of subcelltypes from the database, put them in
-  the Trace Manual combobox and if the string is not empty, the combobox will have as
+  the Trace Settings combobox and if the string is not empty, the combobox will have as
   selected item the string
   \param[in] iSubCellTypeToSelect name of the subcelltype to be selected
   */
-  void SetTMListSubCellTypes(std::string iSubCellTypeToSelect = "");
+  void SetTSListSubCellTypes(std::string iSubCellTypeToSelect = "");
 
   /**
   \brief get the list of subcelltypes from the database, put them in
-  the Trace Manual combobox and the combobox will have as selected item the one
+  the Trace Settings combobox and the combobox will have as selected item the one
   previously selected
   */
-  void SetTMListSubCellTypesWithPreviousSelectedOne();
+  void SetTSListSubCellTypesWithPreviousSelectedOne();
 
   /**
   \brief get the data for the colorcombobox from the database,
-  put them in the Trace Manual colorcombobox and if the string is not empty,
+  put them in the Trace Settings colorcombobox and if the string is not empty,
   the combobox will have as selected item the string
   \param[in] iColorToSelect name of the color to be selected in the combobox
   */
-  void SetTMListColors(std::string iColorToSelect = "");
+  void SetTSListColors(std::string iColorToSelect = "");
 
   /**
   \brief get the list of colors from the database, put them in
-  the Trace Manual combobox and the combobox will have as selected item the one
+  the Trace Settings combobox and the combobox will have as selected item the one
   previously selected
   */
-  void SetTMListColorsWithPreviousSelectedOne();
+  void SetTSListColorsWithPreviousSelectedOne();
 
-  //******************End of Methods related to Trace Manual Editing
+  //******************End of Methods related to Trace Settings Editing
   // Widget***********
 
   /**
@@ -399,7 +442,7 @@ protected:
   std::list< ItemColorComboboxData > GetListCollectionIDFromDB(
     vtkMySQLDatabase *iDatabaseConnector, std::string & ioIDToSelect);
 
-  void closeEvent(QCloseEvent *event);
+  //void closeEvent(QCloseEvent *event);
 
   /**
   \brief set all the traces manager
@@ -413,6 +456,11 @@ protected:
   */
   void GetContentAndDisplayAllTracesInfo(vtkMySQLDatabase *iDatabaseConnector);
 
+  void GetContentAndDisplayAllTracesInfoFor3TPs(vtkMySQLDatabase *iDatabaseConnector);
+
+  void RemoveTracesFromListTimePoints(
+  vtkMySQLDatabase *iDatabaseConnector, std::list<unsigned int> iListTimePoints);
+
   /**
   \brief get the RGB Alpha values from the iTraceRow and set a QColor with them
   \tparam T any children of GoDBTraceRow
@@ -420,20 +468,20 @@ protected:
   \param[in] iDatabaseConnector connection to the database
   \return QColor with the values corresponding to the color values of the iTraceRow
   */
-  template< typename T >
+  /*template< typename T >
   QColor GetQColorFromTraceRow(T iTraceRow, vtkMySQLDatabase *iDatabaseConnector)
   {
     GoDBColorRow ColorRow;
 
-    ColorRow.SetValuesForSpecificID(atoi( iTraceRow.GetMapValue("ColorID").c_str() ),
+    ColorRow.SetValuesForSpecificID(iTraceRow.GetMapValue<int>("ColorID"),
                                     iDatabaseConnector);
-    QColor Color( atoi( ColorRow.GetMapValue("Red").c_str() ),
-                  atoi( ColorRow.GetMapValue("Green").c_str() ),
-                  atoi( ColorRow.GetMapValue("Blue").c_str() ),
-                  atoi( ColorRow.GetMapValue("Alpha").c_str() ) );
+    QColor Color( ColorRow.GetMapValue<int>("Red"),
+                  ColorRow.GetMapValue<int>("Green"),
+                  ColorRow.GetMapValue<int>("Blue"),
+                  ColorRow.GetMapValue<int>("Alpha") );
     return Color;
   }
-
+*/
   /**
   \brief set the color of the traceRow according to the iColor
   \param[in,out] ioRow traceRow with the color to be set up
@@ -474,8 +522,8 @@ protected:
   /** todo once lineage container is set up, the bool track needs to be
     removed*/
   /**
-  \brief delete the checked traces from the database,TW,visu container, 
-  udpate the collectionof collectionID in database and TW and update the 
+  \brief delete the checked traces from the database,TW,visu container,
+  udpate the collectionof collectionID in database and TW and update the
   bounding box of the collection
   \param[in] iTraceManager the manager for the trace expl: mesh_manager
   \param[in] iCollectionManager the manager for the collection expl: track
@@ -487,17 +535,20 @@ protected:
   template< typename TTrace, typename TCollection, typename TCollectionOf >
   void DeleteCheckedTraces(TTrace *iTraceManager,
                     TCollection *iCollectionManager, TCollectionOf *iCollectionOfManager,
-                    bool track = false)
+                    bool lineage = false)
+                    //bool track = false)
   {
     std::list< unsigned int > ListTracesToDelete =
       iTraceManager->GetListHighlightedIDs();
-    std::list<unsigned int> ListCollectionsIDs = 
+    std::list<unsigned int> ListCollectionsIDs =
       this->UpdateCollectionDataForTracesToBeDeleted<TTrace, TCollectionOf>
       (iTraceManager, iCollectionOfManager, ListTracesToDelete);
     this->OpenDBConnection();
     iTraceManager->DeleteCheckedTraces(this->m_DatabaseConnector);
-    if ( !ListCollectionsIDs.empty() || track )
+
+    if ( !ListCollectionsIDs.empty() || !lineage )
       {
+      this->OpenDBConnection(); //in some cases the DeleteCheckedTraces closes the connection
       iCollectionManager->UpdateBoundingBoxes(this->m_DatabaseConnector, ListCollectionsIDs);
       }
     this->CloseDBConnection();
@@ -505,7 +556,7 @@ protected:
 
   /**
   \brief delete the traces of iListTracesToDelete from the database,TW,
-  visu container, udpate the collectionof collectionID in database and TW and update the 
+  visu container, udpate the collectionof collectionID in database and TW and update the
   bounding box of the collection
   \param[in] iTraceManager the manager for the trace expl: mesh_manager
   \param[in] iCollectionManager the manager for the collection expl: track
@@ -519,21 +570,22 @@ protected:
   void DeleteListTraces(TTrace *iTraceManager,
                     TCollection *iCollectionManager, TCollectionOf *iCollectionOfManager,
                     std::list<unsigned int> iListTracesToDelete,
-                    bool track = false)
+                    bool lineage = false)
   {
     std::list<unsigned int> ListCollectionsIDs =
       this->UpdateCollectionDataForTracesToBeDeleted<TTrace, TCollectionOf>
       (iTraceManager, iCollectionOfManager, iListTracesToDelete);
     this->OpenDBConnection();
     iTraceManager->DeleteListTraces(this->m_DatabaseConnector, iListTracesToDelete);
-    if ( !ListCollectionsIDs.empty() || track )
+
+    if ( !ListCollectionsIDs.empty() || !lineage )
       {
       iCollectionManager->UpdateBoundingBoxes(this->m_DatabaseConnector, ListCollectionsIDs);
       }
     this->CloseDBConnection();
   }
   /**
-  \brief udpate the collectionof collectionID in database and TW 
+  \brief udpate the collectionof collectionID in database and TW
   \param[in] iTraceManager the manager for the trace expl: mesh_manager
   \param[in] iCollectionOfManager the manager for the collectioof expl: contour
   \param[in] iListTracesToDelete list of the traceIDs to be deleted
@@ -577,6 +629,7 @@ protected:
     TCollection *iCollectionManager, unsigned int iCollectionID,
     std::list< unsigned int > iListCheckedTraces)
   {
+    this->OpenDBConnection();
     //get the list of CollectionIDs that will be updated:
     std::list< unsigned int > ListCollectionIDsToUpdate =
       iTraceManager->GetListCollectionIDs(this->m_DatabaseConnector,
@@ -585,29 +638,42 @@ protected:
     iTraceManager->UpdateCollectionID(this->m_DatabaseConnector,
                                       iListCheckedTraces, iCollectionID);
 
-    ListCollectionIDsToUpdate.push_back(iCollectionID);
+    if (iCollectionID != 0)
+      {
+      ListCollectionIDsToUpdate.push_back(iCollectionID);
+      }
     iCollectionManager->UpdateBoundingBoxes(this->m_DatabaseConnector,
                                             ListCollectionIDsToUpdate);
+  this->CloseDBConnection();
   }
 
   void UpdateSelectedCollectionForTableWidget(std::string iTableName);
-  
+
 //-------------------------------------------------------------------------
 
 //-------------------------------------------------------------------------
 protected slots:
   void CreateContextMenu(const QPoint & iPos);
 
-  void TheTabIsChanged(int iIndex);
+  /**
+  \brief show/hide the Trace Settings widget depending on the checkstate of
+  the action in the context menu of the dockwidget
+  */
+  void ShowHideTraceSettingsFromContextMenu(bool isVisible);
+
+  /**
+  \brief slot connected to the combobox for the trace in the trace settings widget
+  */
+  void TheTraceHasChanged(int iIndex);
 
   /**
   \brief get a list of the IDs with their colors for the collection corresponding to
   the tracename, for the given timepoint if the
   collection is a mesh or for all timepoints for tracks and lineages,
-  update the Trace Manual colorcombobox and select the corresponding ID in the combobox
+  update the Trace Settings colorcombobox and select the corresponding ID in the combobox
   if the string is not empty
   */
-  void SetTMListCollectionID();
+  void SetTSListCollectionID();
 
   /**
   \brief open the connection to the database and pass it to the ContoursManager
@@ -624,6 +690,11 @@ protected slots:
   */
   void PassDBConnectionToTracksManager();
 
+   /**
+  \brief open the connection to the database and pass it to the LineagesManager
+  */
+  void PassDBConnectionToLineagesManager();
+
   void CloseDBConnection();
   /**
   \brief slot connected to the TraceColorToChange() emitted by the
@@ -637,6 +708,12 @@ protected slots:
   */
   void ChangeTrackColor();
 
+  /**
+  \brief slot connected to the TraceColorToChange() emitted by the
+  m_MeshesManager
+  */
+  void ChangeLineageColor();
+
   /**
   \brief slot connected to the signal TracesToDelete() emitted by the
   m_ContoursManager
@@ -655,6 +732,12 @@ protected slots:
   */
   void DeleteCheckedTracks();
 
+  /**
+  \brief slot connected to the signal TracesToDelete() emitted by the
+  m_LineagesManager
+  */
+  void DeleteCheckedLineages();
+
   /**
   \brief create a new track and call the AddCheckedTracesToCollection template method
   to add the meshes from the list to this new track
@@ -677,6 +760,16 @@ protected slots:
   */
   void CreateNewMeshFromCheckedContours(std::list< unsigned int > iListCheckedContours);
 
+  /**
+  \brief slot connected to the signal NewLineageToCreateFromTracks() emitted by
+  the m_TracksManager
+  \param[in] iListTracks list of the tracksIDs to be part of the new lineage
+  \param[in] iTrackIDRoot ID of the track to be the root of the new lineage to be created
+  \param[in] iLineagesToDelete
+  */
+  void CreateNewLineageFromTracks(std::list< unsigned int > iListCheckedTracks,
+    unsigned int iTrackIDRoot, std::list<unsigned int> iLineagesToDelete);
+
   /**
   \brief slot connected to the the signal CheckedTracesToAddToSelectedCollection
   emitted by m_ContoursManager, which call the AddCheckedTracesToCollection template
@@ -693,6 +786,18 @@ protected slots:
   */
   void AddCheckedMeshesToSelectedTrack(std::list< unsigned int > iListCheckedMeshes);
 
+  /**
+  \brief call the AddCheckedTracesToCollection template and give the info to the
+  lineages manager to create the division in the visu
+  \param[in] iLineageID
+  \param[in] iListDaughters ID of the tracks to be updated with lineageID
+  \param[in] iListLineagesToDelete list of lineageID that need to be deleted as they
+  don't have any tracks belonging to them anymore
+  */
+  void AddCheckedTracksToSelectedLineage(
+    std::list<unsigned int> iListDaughters, unsigned int iLineageID,
+    std::list<unsigned int> iListLineagesToDelete);
+
   /**
   \brief emit a signal TraceToReedit and set m_ReeditMode to true
   \param[in] iTraceID ID of the trace to reedit
@@ -717,8 +822,8 @@ protected slots:
 
   /**
   \brief slot called after signal TrackIDToBeModifiedWithWidget sent by
-  tracksManager, display the checked tracks in a widget allowing the user to 
-  split and merge them and save the results in the database if the user clicks 
+  tracksManager, display the checked tracks in a widget allowing the user to
+  split and merge them and save the results in the database if the user clicks
   the OK button
   \param[in] iTrackIDs checked tracks
   */
@@ -792,9 +897,9 @@ protected slots:
   */
   void DeleteColor();
 
-  //**********************End TraceManualEditingWidget slots
-  // related****************
+  //**********************End TraceSettingsWidget slots // related****************
 private:
+  std::list<unsigned int> m_VisibleTimePoints;
   Q_DISABLE_COPY(QGoPrintDatabase);
 };
 
