@@ -44,9 +44,13 @@
 #include <iostream>
 
 //--------------------------------------------------------------------------
-QGoTabElementBase::QGoTabElementBase(QWidget *iParent) : QWidget(iParent),
+QGoTabElementBase::QGoTabElementBase(QWidget *iParent)
+  : QMainWindow(iParent),
   m_StatusBar(NULL)
+  //m_TracesActions(NULL),
+  //m_TraceSettingsToolBar(NULL),
 {
+  //this->m_TracesActions = new QGoToolBarStatus;
 }
 
 //--------------------------------------------------------------------------
@@ -66,6 +70,13 @@ std::vector< QAction * > QGoTabElementBase::ViewActions()
 
 //--------------------------------------------------------------------------
 
+//--------------------------------------------------------------------------
+std::vector< QAction * > QGoTabElementBase::ViewNoToolBarActions()
+{
+  return this->m_ViewNoToolBarActions;
+}
+//--------------------------------------------------------------------------
+
 //--------------------------------------------------------------------------
 std::vector< QAction * > QGoTabElementBase::SegmentationActions()
 {
@@ -91,13 +102,37 @@ std::vector< QAction * > QGoTabElementBase::BookmarkActions()
 //--------------------------------------------------------------------------
 
 //--------------------------------------------------------------------------
-std::vector< QAction * > QGoTabElementBase::ModeActions()
-{
-  return m_ModeActions;
-}
+//std::vector< QAction * > QGoTabElementBase::ModeActions()
+//{
+//  return m_ModeActions;
+//}
 
 //--------------------------------------------------------------------------
 
+//--------------------------------------------------------------------------
+//std::vector< QAction * > QGoTabElementBase::TracesActions()
+//QGoToolBarStatus* QGoTabElementBase::TracesActions()
+//{
+//  return m_TracesActions;
+//}
+
+////--------------------------------------------------------------------------
+
+////--------------------------------------------------------------------------
+//QGoTraceSettingsWidget*  QGoTabElementBase::TraceSettingsWidget()
+//{
+//  return m_TraceSettingsWidgetForToolBar;
+//}
+////--------------------------------------------------------------------------
+
+////--------------------------------------------------------------------------
+//void QGoTabElementBase::SetTraceSettingsToolBar(
+//  QToolBar* iToolBar)
+//{
+//  this->m_TraceSettingsToolBar = iToolBar;
+//}
+//--------------------------------------------------------------------------
+
 //--------------------------------------------------------------------------
 std::list< QGoTabElementBase::QGoDockWidgetStatusPair > &
 QGoTabElementBase::DockWidget()
@@ -124,15 +159,23 @@ void QGoTabElementBase::SetPluginActions(std::list< QAction * > iList)
 //--------------------------------------------------------------------------
 
 //-------------------------------------------------------------------------
-void QGoTabElementBase::CreateModeActions(QActionGroup *group)
+void QGoTabElementBase::CreateModeToolBar(
+  QMenu* iMenu, QToolBar* iToolBar)
 {
+  QActionGroup* ModeGroup = new QActionGroup(this);
+  ModeGroup->setObjectName("ModeGroup");
+
+  this->m_ModeToolBar = new QGoToolBarStatus(iToolBar, iMenu, Qt::TopToolBarArea,
+      true, true, this);
   //---------------------------------//
   //           default mode          //
   //---------------------------------//
 
   // Create/initialize the default action
   QAction *DefaultAction = new QAction(tr("Default"), this);
-  DefaultAction->setShortcut( tr("1", "Default Mode"));
+  DefaultAction->setShortcut(tr("1", "Default Mode"));
+  DefaultAction->setObjectName("DefaultMode");
+
   DefaultAction->setCheckable(true);
   DefaultAction->setChecked(true);
 
@@ -141,20 +184,20 @@ void QGoTabElementBase::CreateModeActions(QActionGroup *group)
                         QIcon::Normal, QIcon::Off);
   DefaultAction->setIcon(DefaultIcon);
 
-  group->addAction(DefaultAction);
+  ModeGroup->addAction(DefaultAction);
 
   // it also updates the interactor behaviour
   QObject::connect( DefaultAction, SIGNAL( toggled(bool) ),
                     this, SLOT( DefaultInteractorBehavior(bool) ) );
 
-  this->m_ModeActions.push_back(DefaultAction);
+  this->m_ModeToolBar->m_VectorAction.push_back(DefaultAction);
 
   //---------------------------------//
   //            Zoom mode            //
   //---------------------------------//
 
   QAction *ZoomAction = new QAction(tr("Zoom"), this);
-  ZoomAction->setShortcut( tr("Z", "Zoom Mode"));
+  ZoomAction->setShortcut(tr("Z", "Zoom Mode"));
   ZoomAction->setCheckable(true);
   ZoomAction->setChecked(false);
 
@@ -163,9 +206,9 @@ void QGoTabElementBase::CreateModeActions(QActionGroup *group)
                      QIcon::Normal, QIcon::Off);
   ZoomAction->setIcon(ZoomIcon);
 
-  group->addAction(ZoomAction);
+  ModeGroup->addAction(ZoomAction);
 
-  this->m_ModeActions.push_back(ZoomAction);
+  this->m_ModeToolBar->m_VectorAction.push_back(ZoomAction);
   // it also updates the interactor behaviour
   QObject::connect( ZoomAction, SIGNAL( toggled(bool) ),
                     this, SLOT( ZoomInteractorBehavior(bool) ) );
@@ -175,7 +218,7 @@ void QGoTabElementBase::CreateModeActions(QActionGroup *group)
   //---------------------------------//
 
   QAction *TranslateAction = new QAction(tr("Translate"), this);
-  TranslateAction->setShortcut( tr("T", "Translate Mode"));
+  TranslateAction->setShortcut(tr("T", "Translate Mode"));
   TranslateAction->setCheckable(true);
   TranslateAction->setChecked(false);
 
@@ -184,18 +227,33 @@ void QGoTabElementBase::CreateModeActions(QActionGroup *group)
                     QIcon::Normal, QIcon::Off);
   TranslateAction->setIcon(TranslateIcon);
 
-  group->addAction(TranslateAction);
+  ModeGroup->addAction(TranslateAction);
 
-  this->m_ModeActions.push_back(TranslateAction);
+  this->m_ModeToolBar->m_VectorAction.push_back(TranslateAction);
   // it also updates the interactor behaviour
   QObject::connect( TranslateAction, SIGNAL( toggled(bool) ),
                     this, SLOT( TranslateInteractorBehavior(bool) ) );
+
+  this->m_ToolBarList.push_back(this->m_ModeToolBar);
 }
 
 //--------------------------------------------------------------------------
 
+//-------------------------------------------------------------------------
+void QGoTabElementBase::CreateViewToolBar(QMenu* iMenu, QToolBar* iToolBar)
+{
+}
+//--------------------------------------------------------------------------
+
 //-------------------------------------------------------------------------
 void QGoTabElementBase::SetStatusBarPointer(QStatusBar *iStatusbar)
 {
   this->m_StatusBar = iStatusbar;
 }
+//--------------------------------------------------------------------------
+
+//-------------------------------------------------------------------------
+std::list< QGoToolBarStatus* > QGoTabElementBase::GetToolBarsStatus()
+{
+  return this->m_ToolBarList;
+}
