@@ -35,7 +35,7 @@
 #ifndef __QGoTabElementBase_h
 #define __QGoTabElementBase_h
 
-#include <QWidget>
+#include <QMainWindow>
 #include <QDir>
 #include <QStatusBar>
 
@@ -43,6 +43,8 @@
 #include "QGoDockWidgetStatus.h"
 
 #include "QGoGUILibConfigure.h"
+#include "QGoTraceSettingsWidget.h"
+#include "QGoToolBarStatus.h"
 
 class QAction;
 class QActionGroup;
@@ -56,7 +58,7 @@ class QGoPluginManager;
 \brief Abstract class for one tab element in GoFigure2.
 \example GUI/lib/qgotabelementbase.cxx
 */
-class QGOGUILIB_EXPORT QGoTabElementBase:public QWidget
+class QGOGUILIB_EXPORT QGoTabElementBase:public QMainWindow
 {
   Q_OBJECT
 public:
@@ -71,9 +73,14 @@ public:
   /** \brief Get the dimension type of the underlying data set.*/
   virtual GoFigure::TabDimensionType GetTabDimensionType() const = 0;
 
+  virtual std::list< QGoToolBarStatus* > GetToolBarsStatus();
+
   /** \brief Get all actions belonging to View Menu and Toolbar.*/
   virtual std::vector< QAction * > ViewActions();
 
+  /** \brief Get all actions belonging to View Menu only.*/
+  virtual std::vector< QAction * > ViewNoToolBarActions();
+
   /** \brief Get all actions belonging to Segmentation Menu and Toolbar. */
   virtual std::vector< QAction * > SegmentationActions();
 
@@ -84,7 +91,14 @@ public:
   virtual std::vector< QAction * > BookmarkActions();
 
   /** \brief Get all actions belonging to Mode Menu and Toolbar.*/
-  virtual std::vector< QAction * > ModeActions();
+  //virtual std::vector< QAction * > ModeActions();
+
+  /** \brief Get all actions belonging to the Traces Toolbar.*/
+  //virtual std::vector< QAction * > TracesActions();
+  //virtual QGoToolBarStatus* TracesActions();
+
+  /** \brief Get the widget for the trace settings to be added in the TraceSettings Toolbar*/
+  //virtual QGoTraceSettingsWidget* TraceSettingsWidget();
 
   /** \brief Get all the DockWidgets with its status (visibility, location). */
   virtual std::list< QGoDockWidgetStatusPair > & DockWidget();
@@ -101,8 +115,6 @@ public:
   /** \brief Read Settings for the related tab element.*/
   virtual void ReadSettings() = 0;
 
-  void CreateModeActions(QActionGroup *group);
-
   /**
    * \brief Mouse interaction style set as default
    */
@@ -119,17 +131,31 @@ public:
 
   void SetStatusBarPointer(QStatusBar* iStatusbar);
 
+  //virtual void SetTraceSettingsToolBar(QToolBar* iToolBar);
+
+  virtual void CreateModeToolBar(QMenu* iMenu, QToolBar* iToolBar);
+  virtual void CreateViewToolBar(QMenu* iMenu, QToolBar* iToolBar);
+
 protected:
   std::list< QAction * > m_PluginActionList;
 
   std::vector< QAction * > m_ViewActions;
+  QGoToolBarStatus*        m_ViewActionsMenuToolBar;
+  std::vector< QAction* >  m_ViewNoToolBarActions;
   std::vector< QAction * > m_SegmentationActions;
   std::vector< QAction * > m_ToolsActions;
   std::vector< QAction * > m_BookmarkActions;
-  std::vector< QAction * > m_ModeActions;
+  //std::vector< QAction * > m_ModeActions;
+  QGoToolBarStatus*        m_ModeToolBar;
+  //std::vector< QAction * > m_TracesActions;
+  //QGoToolBarStatus*        m_TracesActions;
+  //QGoTraceSettingsWidget*  m_TraceSettingsWidgetForToolBar;
+  //QToolBar*                m_TraceSettingsToolBar;
+
+  std::list< QGoDockWidgetStatusPair >  m_DockWidgetList;
+  std::list< QGoToolBarStatus* >        m_ToolBarList;
+  QStatusBar*                           m_StatusBar;
 
-  std::list< QGoDockWidgetStatusPair > m_DockWidgetList;
-  QStatusBar*              m_StatusBar;
 private:
   Q_DISABLE_COPY(QGoTabElementBase);
 };
