@@ -184,46 +184,35 @@ QGoTrackEditingWidget::updateCurrentActorSelection(vtkObject *caller)
       cutTrack(m_CurrentActor);
       }
     }
-  else
+  /*else
     {
-    if ( realMeshes->isChecked() )
-      {
-      MeshContainer::MultiIndexContainerActorXYIterator iter, c_end;
-      iter = m_MeshContainer->m_Container.get< ActorXY >().find(m_CurrentActor);
-      c_end = m_MeshContainer->m_Container.get< ActorXY >().end();
-      merge< MeshContainer::MultiIndexContainerActorXYIterator >(iter, c_end);
-      }
-    else
-      {
-      MeshContainer::MultiIndexContainerActorXZIterator iter, c_end;
-      iter = m_MeshContainer->m_Container.get< ActorXZ >().find(m_CurrentActor);
-      c_end = m_MeshContainer->m_Container.get< ActorXZ >().end();
-      merge< MeshContainer::MultiIndexContainerActorXZIterator >(iter, c_end);
-      }
-    }
+    MeshContainer::MultiIndexContainerTraceIDIterator iter;
+    vtkIntArray* testArray =
+        static_cast<vtkIntArray*>(m_CurrentActor->GetMapper()->GetInput()
+            ->GetPointData()->GetArray("MESH"));
+    iter = m_MeshContainer->m_Container.get< TraceID >().find( testArray->GetValue(0) );
+    assert(iter != m_MeshContainer->m_Container.get< TraceID >().end() );
+    merge(iter);
+    }*/
 }
 
 //-------------------------------------------------------------------------
 
 //-------------------------------------------------------------------------
-template< class TIterator >
 void
-QGoTrackEditingWidget::merge(TIterator iBegin, TIterator iEnd)
+QGoTrackEditingWidget::merge(MeshContainer::MultiIndexContainerTraceIDIterator iBegin)
 {
-  if ( iBegin != iEnd )
+  if ( m_SecondClick )
     {
-    if ( m_SecondClick )
-      {
-      mergeTrack(m_FirstMeshID, iBegin->TraceID);
-      }
-    else
-      {
-      m_FirstMeshID    = iBegin->TraceID;
-      m_FirstMeshActor = m_CurrentActor;
-      m_StatusBar->showMessage("Select another mesh to merge tracks");
-      }
-    highlightFirstActor(!m_SecondClick);
+    mergeTrack(m_FirstMeshID, iBegin->TraceID);
     }
+  else
+    {
+    m_FirstMeshID    = iBegin->TraceID;
+    m_FirstMeshActor = m_CurrentActor;
+    m_StatusBar->showMessage("Select another mesh to merge tracks");
+    }
+  highlightFirstActor(!m_SecondClick);
 }
 
 //-------------------------------------------------------------------------
@@ -278,6 +267,8 @@ QGoTrackEditingWidget::initializeVisualization()
 
   computeMeshActors();
 
+  this->updateMeshesActors( false );
+
   computeLineActors();
 
   computeLabelActor();
@@ -305,6 +296,15 @@ QGoTrackEditingWidget::computeMeshActors()
       vtkPolyData *nodes = tempStructure.Nodes;
       double *     rgba = tempStructure.rgba;
 
+      // add trace info in the polydata
+      vtkSmartPointer<vtkIntArray> trackIDArray = vtkSmartPointer<vtkIntArray>::New();
+      trackIDArray->SetNumberOfComponents(1);
+      trackIDArray->SetNumberOfValues(1);
+      trackIDArray->SetName("MESH");
+      trackIDArray->SetValue(0,tempStructure.TraceID);
+
+      nodes->GetPointData()->AddArray(trackIDArray);
+
       //setup actor and mapper
       vtkSmartPointer< vtkPolyDataMapper > mapper =
         vtkSmartPointer< vtkPolyDataMapper >::New();
@@ -317,7 +317,8 @@ QGoTrackEditingWidget::computeMeshActors()
       // generate sphere based on the minimal distance between 2 points in a
       // track
       // actors are invisible
-      vtkActor *sphereActor = computeSphere(actor->GetCenter(), m_MinimalDistance / 3);
+      vtkActor *sphereActor = computeSphere(tempStructure.TraceID,
+          actor->GetCenter(), m_MinimalDistance / 3);
       tempStructure.ActorXZ = sphereActor;
 
       // Add actor to visu
@@ -793,10 +794,10 @@ void
 QGoTrackEditingWidget::updateMeshesActors(bool iRealMeshes)
 {
   // Go through container and update visibility
-  MeshContainer::MultiIndexContainerActorXYIterator iter, c_end;
+  MeshContainer::MultiIndexContainerTraceIDIterator iter, c_end;
 
-  iter = m_MeshContainer->m_Container.get< ActorXY >().begin();
-  c_end = m_MeshContainer->m_Container.get< ActorXY >().end();
+  iter = m_MeshContainer->m_Container.get< TraceID >().begin();
+  c_end = m_MeshContainer->m_Container.get< TraceID >().end();
 
   while ( iter != c_end )
     {
@@ -813,17 +814,27 @@ QGoTrackEditingWidget::updateMeshesActors(bool iRealMeshes)
 
 //-------------------------------------------------------------------------
 vtkActor *
-QGoTrackEditingWidget::computeSphere(double *iCenter, double iRadius)
+QGoTrackEditingWidget::computeSphere(unsigned int iTraceID, double *iCenter, double iRadius)
 {
   // Sphere
   vtkSmartPointer< vtkSphereSource > sphereSource =
     vtkSmartPointer< vtkSphereSource >::New();
   sphereSource->SetCenter(iCenter);
   sphereSource->SetRadius(iRadius);
+  sphereSource->Update();
+
+  // add trace ID into the polydata
+  vtkSmartPointer<vtkIntArray> trackIDArray = vtkSmartPointer<vtkIntArray>::New();
+  trackIDArray->SetNumberOfComponents(1);
+  trackIDArray->SetNumberOfValues(1);
+  trackIDArray->SetName("MESH");
+  trackIDArray->SetValue(0,iTraceID);
+
+  sphereSource->GetOutput()->GetPointData()->AddArray(trackIDArray);
 
   vtkSmartPointer< vtkPolyDataMapper > sphereMapper =
     vtkSmartPointer< vtkPolyDataMapper >::New();
-  sphereMapper->SetInputConnection( sphereSource->GetOutputPort() );
+  sphereMapper->SetInput( sphereSource->GetOutput() );
 
   vtkActor *sphereActor = vtkActor::New();
   sphereActor->SetMapper(sphereMapper);
@@ -863,4 +874,4 @@ QGoTrackEditingWidget::getClosestPoints()
     it2 = m_MeshContainer->m_Container.get< TraceID >().begin();
     ++it;
     }
-}
\ No newline at end of file
+}
