@@ -1,3 +1,4 @@
+
 /*=========================================================================
  Authors: The GoFigure Dev. Team.
  at Megason Lab, Systems biology, Harvard Medical school, 2009-11
@@ -182,9 +183,17 @@ public:
     std::string CollectionID = iNewCollection.GetMapValue(this->m_CollectionIDName);
     if ( CollectionID != "0" )
       {
-      return this->CreateNewTraceInDB< T >( iNewCollection, iDatabaseConnector,
-                                            CoordIDMin, CoordIDMax, iColor,
-                                            ss_atoi< unsigned int >(CollectionID) );
+      if (CollectionID == "noValue") //case for lineage
+        {
+        return this->CreateNewTraceInDB< T >( iNewCollection, iDatabaseConnector,
+                                              CoordIDMin, CoordIDMax, iColor);
+        }
+      else
+        {
+        return this->CreateNewTraceInDB< T >( iNewCollection, iDatabaseConnector,
+                                              CoordIDMin, CoordIDMax, iColor,
+                                              ss_atoi< unsigned int >(CollectionID) );
+        }
       }
     else
       {
@@ -216,7 +225,7 @@ public:
   }
 
   /**
-  \overload 
+  \overload
   */
   template< typename T >
   unsigned int CreateNewTraceInDB(T iTrace, vtkMySQLDatabase *iDatabaseConnector,
@@ -233,6 +242,22 @@ public:
     return iTrace.SaveInDB(iDatabaseConnector);
   }
 
+  /**
+  \overload
+  */
+  template< typename T > //for lineage
+  unsigned int CreateNewTraceInDB(T iTrace, vtkMySQLDatabase *iDatabaseConnector,
+                                  unsigned int iCoordIDMin, unsigned int iCoordIDMax,
+                                  NameWithColorData iColor)
+  {
+    iTrace.SetField( "CoordIDMin", ConvertToString< unsigned int >(iCoordIDMin) );
+    iTrace.SetField( "CoordIDMax", ConvertToString< unsigned int >(iCoordIDMax) );
+    iTrace.SetColor(iColor.second.red(), iColor.second.green(),
+                    iColor.second.blue(), iColor.second.alpha(), iColor.first,
+                    iDatabaseConnector);
+    return iTrace.SaveInDB(iDatabaseConnector);
+  }
+
   /**
   \brief update the color of the specified trace with iNewColor in the database
   \param[in] iTraceID ID of the trace with the color to modify
@@ -266,10 +291,13 @@ public:
  \brief get the list of IDs that are collection of iListTraces
  \param[in] iDatabaseConnector connection to the database
  \param[in] iListTracesIDs list of traces IDs for which we need the collectionIDs
+ \param[in] ExcludeZero if set to true, will not return the collectionID = 0
+ \param[in] Distinct if set to true, will not return doublon
  \return std::list<unsigned int> list of the tracesIDs
  */
   std::list< unsigned int > GetListCollectionIDs(
-    vtkMySQLDatabase *iDatabaseConnector, std::list< unsigned int > iListTracesIDs);
+    vtkMySQLDatabase *iDatabaseConnector, std::list< unsigned int > iListTracesIDs,
+    bool ExcludeZero = true, bool Distinct = true);
 
   /**
   \brief get the list of tracesIDs that have no points
@@ -388,6 +416,9 @@ public:
   std::list<unsigned int> GetTraceIDsBelongingToCollectionID(
     vtkMySQLDatabase *iDatabaseConnector,std::list<unsigned int> iListCollectionIDs);
 
+  std::list<unsigned int> GetTraceIDsBelongingToListTimePoints(
+    vtkMySQLDatabase *iDatabaseConnector,std::list<unsigned int> iListTPs);
+
   /**
   \brief get the timepoints (non distinct) for all the traceIDs in iListTraceIDs
   \param[in] iDatabaseConnector connection to the database
@@ -413,13 +444,13 @@ public:
   \brief get the timepoint min or max for the trace
   \param[in] iDatabaseConnector connection to the database
   \param[in] iTraceID ID of the trace the timepoint min is needed
-  \param[in] MinTimePoint if true return the min timepoint, if false, 
+  \param[in] MinTimePoint if true return the min timepoint, if false,
   return the max timepoint
   \return the timepoint min or max
   */
   unsigned int GetBoundedBoxTimePoint(
     vtkMySQLDatabase *iDatabaseConnector, unsigned int iTraceID, bool MinTimePoint = true);
- 
+
   /**
   \brief get a list of structures filled with data from the database
   \param[in] iDatabaseConnector connection to the database
@@ -430,7 +461,7 @@ public:
   */
   template<typename T>
   std::list<T> GetListStructureFromDB(
-    vtkMySQLDatabase* iDatabaseConnector, unsigned int iImgSessionID, 
+    vtkMySQLDatabase* iDatabaseConnector, unsigned int iImgSessionID,
     std::list<unsigned int> iListTraces)
 {
   std::list<T> oListTracesResults;
@@ -439,12 +470,40 @@ public:
   FieldWithValue ColorCondition = {"ColorID", "ColorID", "="};
 
   GetInfoFromDBAndModifyListStructure<T>(
-    oListTracesResults, iDatabaseConnector, 
-    TraceAttributes, this->m_TracesName, "coordinate", "color", 
+    oListTracesResults, iDatabaseConnector,
+    TraceAttributes, this->m_TracesName, "coordinate", "color",
     CoordinateCondition, ColorCondition, "ImagingSessionID",
     iImgSessionID, this->m_TracesIDName, iListTraces);
   return oListTracesResults;
 }
+  /**
+  \brief return the traceID with the lowest timepoint or -1 if there
+  is not only one that have the lowest timepoint
+  */
+  int GetTraceIDWithLowestTimePoint(vtkMySQLDatabase *iDatabaseConnector,
+    std::list<unsigned int> iListTraceIDs);
+
+  std::list<unsigned int> GetTrackFamilyDataFromDB(
+    vtkMySQLDatabase *iDatabaseConnector);
+
+  std::list<unsigned int> GetTrackFamiliesForLineages(
+    vtkMySQLDatabase *iDatabaseConnector, std::list<unsigned int> iLineagesID);
+
+  /**
+  \brief return the trackFamilyIDs the track belongs to (as a mother or as
+  a daughter)
+  */
+  std::list<unsigned int> GetTrackFamilyID(vtkMySQLDatabase *iDatabaseConnector,
+    std::list<unsigned int> iListTrackIDs);
+
+  std::string GetPoints(vtkMySQLDatabase *iDatabaseConnector,
+                        std::string iTraceName,
+                        unsigned int iTraceID);
+
+  std::vector<unsigned int> GetTrackFamily(vtkMySQLDatabase *iDatabaseConnector,
+                                           unsigned int iTrackID);
+
+  bool isMother(vtkMySQLDatabase *iDatabaseConnector, unsigned int iTrackID);
 
 protected:
 
